@@ -9,7 +9,7 @@ class CenterColumnShieldCircular(RotateMixedShape):
     :type height: float
     :param inner_radius: inner radius of the center column shield
     :type inner_radius: float
-    :param mid_radius: inner radius of the outer hyperbolic 
+    :param mid_radius: inner radius of the outer hyperbolic
      profile of the center column shield
     :type mid_radius: float
     :param outer_radius: outer_radius of the center column shield
@@ -25,31 +25,34 @@ class CenterColumnShieldCircular(RotateMixedShape):
         inner_radius,
         mid_radius,
         outer_radius,
-        workplane="XZ",
         rotation_angle=360,
-        solid=None,
-        stp_filename="center_column.stp",
+        stp_filename="CenterColumnShieldCircular.stp",
         color=None,
-        points=None,
         name="center_column",
-        material_tag="center_column_material",
+        material_tag="center_column_shield_mat",
         azimuth_placement_angle=0,
         cut=None,
-        hash_value=None,
+        **kwargs
     ):
 
+        default_dict = {'points':None,
+                        'workplane':"XZ",
+                        'solid':None,
+                        'hash_value':None}
+
+        for arg in kwargs:
+            if arg in default_dict:
+                default_dict[arg] = kwargs[arg]
+
         super().__init__(
-            points,
-            workplane,
-            name,
-            color,
-            material_tag,
-            stp_filename,
-            azimuth_placement_angle,
-            solid,
-            rotation_angle,
-            cut,
-            hash_value,
+            name=name,
+            color=color,
+            material_tag=material_tag,
+            stp_filename=stp_filename,
+            azimuth_placement_angle=azimuth_placement_angle,
+            rotation_angle=rotation_angle,
+            cut=cut,
+            **default_dict
         )
 
         self.height = height
