@@ -20,31 +20,34 @@ class CenterColumnShieldCylinder(RotateStraightShape):
         height,
         inner_radius,
         outer_radius,
-        points=None,
         name=None,
         color=None,
-        workplane="XZ",
-        stp_filename="center_column_shield.stp",
+        stp_filename="CenterColumnShieldCylinder.stp",
         rotation_angle=360,
-        solid=None,
-        material_tag=None,
+        material_tag="center_column_shield_mat",
         azimuth_placement_angle=0,
         cut=None,
-        hash_value=None,
+        **kwargs
     ):
 
+        default_dict = {'points':None,
+                        'workplane':"XZ",
+                        'solid':None,
+                        'hash_value':None}
+
+        for arg in kwargs:
+            if arg in default_dict:
+                default_dict[arg] = kwargs[arg]
+
         super().__init__(
-            points,
-            workplane,
-            name,
-            color,
-            material_tag,
-            stp_filename,
-            azimuth_placement_angle,
-            solid,
-            rotation_angle,
-            cut,
-            hash_value,
+            name=name,
+            color=color,
+            material_tag=material_tag,
+            stp_filename=stp_filename,
+            azimuth_placement_angle=azimuth_placement_angle,
+            rotation_angle=rotation_angle,
+            cut=cut,
+            **default_dict
         )
 
         self.height = height
