@@ -26,31 +26,34 @@ class InnerTfCoilsFlat(ExtrudeStraightShape):
         outer_radius,
         number_of_coils,
         gap_size,
-        points=None,
         distance=None,
-        workplane="XY",
-        stp_filename=None,
-        solid=None,
+        stp_filename="InnerTfCoilsFlat.stp",
         color=None,
         azimuth_placement_angle=0,
         cut=None,
-        material_tag=None,
+        material_tag="inner_tf_coil_mat",
         name=None,
-        hash_value=None,
+        **kwargs
     ):
 
+        default_dict = {'points':None,
+                        'workplane':"XY",
+                        'solid':None,
+                        'hash_value':None}
+
+        for arg in kwargs:
+            if arg in default_dict:
+                default_dict[arg] = kwargs[arg]
+
         super().__init__(
-            points,
-            distance,
-            workplane,
-            stp_filename,
-            solid,
-            color,
-            azimuth_placement_angle,
-            cut,
-            material_tag,
-            name,
-            hash_value,
+            distance=distance,
+            stp_filename=stp_filename,
+            color=color,
+            azimuth_placement_angle=azimuth_placement_angle,
+            cut=cut,
+            material_tag=material_tag,
+            name=name,
+            **default_dict
         )
 
         self.height = height
