@@ -39,31 +39,34 @@ class ToroidalFieldCoilCoatHanger(ExtrudeStraightShape):
         thickness,
         distance,
         number_of_coils,
-        workplane="XZ",
         rotation_angle=360,
-        solid=None,
-        stp_filename="toroidal_field_coil.stp",
+        stp_filename="ToroidalFieldCoilCoatHangar.stp",
         color=None,
         azimuth_placement_angle=0,
-        points=None,
         name=None,
-        material_tag=None,
+        material_tag="outer_tf_coil_mat",
         cut=None,
-        hash_value=None,
+        **kwargs
     ):
 
+        default_dict = {'points':None,
+                        'workplane':"XZ",
+                        'solid':None,
+                        'hash_value':None}
+
+        for arg in kwargs:
+            if arg in default_dict:
+                default_dict[arg] = kwargs[arg]
+
         super().__init__(
-            points,
-            distance,
-            workplane,
-            stp_filename,
-            solid,
-            color,
-            azimuth_placement_angle,
-            cut,
-            material_tag,
-            name,
-            hash_value,
+            distance=distance,
+            stp_filename=stp_filename,
+            color=color,
+            azimuth_placement_angle=azimuth_placement_angle,
+            cut=cut,
+            material_tag=material_tag,
+            name=name,
+            **default_dict
         )
 
         self.horizontal_start_point = horizontal_start_point
