@@ -11,9 +11,8 @@ from hashlib import blake2b
 class ExtrudeStraightShape(Shape):
     """Extrude a 3d CadQuery solid from points connected with straight lines
 
-       :param points: A list of XZ coordinates and connection types where the last
-            entry has the same XZ coordinates as the first entry. For example [(2.,1.),
-            (2.,2.), (1.,2.), (1.,1.), (2.,1.)].
+       :param points: A list of XZ coordinates connected by straight connections. For
+            example [(2.,1.), (2.,2.), (1.,2.), (1.,1.), (2.,1.)].
        :type points: a list of tuples each containing X (float), Z (float)
        :param stp_filename: the filename used when saving stp files as part of a reactor
        :type stp_filename: str
@@ -38,7 +37,7 @@ class ExtrudeStraightShape(Shape):
         points,
         distance,
         workplane="XZ",
-        stp_filename=None,
+        stp_filename="ExtrudeStraightShape.stp",
         solid=None,
         color=None,
         azimuth_placement_angle=0,
@@ -117,8 +116,8 @@ class ExtrudeStraightShape(Shape):
         """Creates a 3d solid using points with straight connections
         edges, azimuth_placement_angle and rotation_angle.
 
-        :return: a 3d solid volume
-        :rtype: a cadquery solid
+        Returns:
+           A CadQuery solid: A 3D solid volume
         """
 
         # print('create_solid() has been called')
