@@ -10,27 +10,20 @@ from hashlib import blake2b
 class RotateCircleShape(Shape):
     """Rotates a circular 3d CadQuery solid from a central point and a radius
 
-       :param points: A list of a single XZ coordinate which is the central
-            point of the circle. For example, [(10, 10)]
-       :type points: a list of tuples each containing X (float), Z (float)
-       :param radius: The radius of the circle
-       :type radius: float
-       :param name: The legend name used when exporting a html graph of the shape
-       :type name: str
-       :param color: the color to use when exporting as html graphs or png images
-       :type color: Red, Green, Blue, [Alpha] values. RGB and RGBA are sequences of,
-            3 or 4 floats respectively each in the range 0-1
-       :param material_tag: The material name to use when exporting the neutronics description
-       :type material_tag: str
-       :param stp_filename: the filename used when saving stp files as part of a reactor
-       :type stp_filename: str
-       :param azimuth_placement_angle: the angle or angles to use when rotating the 
-            shape on the azimuthal axis
-       :type azimuth_placement_angle: float or iterable of floats
-       :param rotation_angle: The rotation_angle to use when revoling the solid (degrees)
-       :type rotation_angle: float
-       :param cut: An optional cadquery object to perform a boolean cut with this object
-       :type cut: cadquery object
+       Args:
+          points (a list of tuples each containing X (float), Z (float)): A list of a single
+             XZ coordinate which is the central point of the circle. For example, [(10, 10)].
+          radius (float): The radius of the circle.
+          name (str): The legend name used when exporting a html graph of the shape.
+          color (RGB or RGBA - sequences of 3 or 4 floats, respectively, each in the range 0-1):
+             The color to use when exporting as html graphs or png images.
+          material_tag (str): The material name to use when exporting the neutronics description.
+          stp_filname (str): The filename used when saving stp files as part of a reactor.
+          azimuth_placement_angle (float or iterable of floats): The angle or angles to use when
+             rotating the shape on the azimuthal axis.
+          rotation_angle (float): The rotation angle to use when revolving the solid (degrees).
+          cut (CadQuery object): An optional CadQuery object to perform a boolean cut with this
+             object.
     """
 
     def __init__(
@@ -38,7 +31,7 @@ class RotateCircleShape(Shape):
         points,
         radius,
         workplane="XZ",
-        stp_filename=None,
+        stp_filename="RotateCircleShape.stp",
         solid=None,
         color=None,
         azimuth_placement_angle=0,
@@ -126,10 +119,10 @@ class RotateCircleShape(Shape):
 
     def create_solid(self):
         """Creates a 3d solid using points, radius, azimuth_placement_angle and
-        rotation_angle.
-        
-        :return: a 3d solid volume
-        :rtype: a cadquery solid
+           rotation_angle.
+
+           Returns:
+              A CadQuery solid: A 3D solid volume
         """
 
         # print('create_solid() has been called')
